summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/test/kbase/KBaseView.java
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kdejava/koala/test/kbase/KBaseView.java
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kdejava/koala/test/kbase/KBaseView.java')
-rw-r--r--kdejava/koala/test/kbase/KBaseView.java10
1 files changed, 5 insertions, 5 deletions
diff --git a/kdejava/koala/test/kbase/KBaseView.java b/kdejava/koala/test/kbase/KBaseView.java
index 2b745b11..59554607 100644
--- a/kdejava/koala/test/kbase/KBaseView.java
+++ b/kdejava/koala/test/kbase/KBaseView.java
@@ -1,16 +1,16 @@
import org.kde.qt.*;
/** The KBaseView class provides the view widget for the KBase instance.
* The View instance inherits QWidget as a base class and represents the view object of a KTMainWindow. As KBaseView is part of the
* docuement-view model, it needs a reference to the document object connected with it by the KBase class to manipulate and display
* the document structure provided by the KBaseDoc class.
*
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 0.4 code generation
*/
-public class KBaseView extends QWidget {
+public class KBaseView extends TQWidget {
-public KBaseView(QWidget parent, String name)
+public KBaseView(TQWidget parent, String name)
{
super(parent, name);
setBackgroundMode(PaletteBase);
@@ -23,9 +23,9 @@ public KBaseDoc getDocument()
return theApp.getDocument();
}
-public void print(QPrinter pPrinter)
+public void print(TQPrinter pPrinter)
{
- QPainter printpainter = new QPainter();
+ TQPainter printpainter = new TQPainter();
printpainter.begin(pPrinter);
// TODO: add your printing code here
@@ -1,16 +1,16 @@
import org.kde.qt.*;
/** The KBaseView class provides the view widget for the KBase instance.
- * The View instance inherits QWidget as a base class and represents the view object of a KTMainWindow. As KBaseView is part of the
+ * The View instance inherits TQWidget as a base class and represents the view object of a KTMainWindow. As KBaseView is part of the
* docuement-view model, it needs a reference to the document object connected with it by the KBase class to manipulate and display
* the document structure provided by the KBaseDoc class.